==> haskell-ed25519-0.0.5.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ed25519.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ed25519
version:              0.0.5.0
visibility:           public
id:                   ed25519-0.0.5.0-GbHyWkjY0ttLaEYpLIK0bd
key:                  ed25519-0.0.5.0-GbHyWkjY0ttLaEYpLIK0bd
license:              MIT
copyright:            Copyright (c) Austin Seipp 2013-2015
maintainer:           Austin Seipp <aseipp@pobox.com>
author:               Austin Seipp
homepage:             http://thoughtpolice.github.com/hs-ed25519
synopsis:             Ed25519 cryptographic signatures
description:
    This package provides a simple, fast, self-contained copy of the
    Ed25519 public-key signature system with a clean interface. It also
    includes support for detached signatures, and thorough documentation
    on the design and implementation, including usage guidelines.

category:             Cryptography
abi:                  cfe5b036094fe8669f5e72719e95af2a
exposed:              True
exposed-modules:      Crypto.Sign.Ed25519
import-dirs:          /usr/lib/ghc-8.10.1/site-local/ed25519-0.0.5.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/ed25519-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/ed25519-0.0.5.0
hs-libraries:         HSed25519-0.0.5.0-GbHyWkjY0ttLaEYpLIK0bd
depends:              base-4.14.0.0 bytestring-0.10.10.0 ghc-prim-0.6.1
haddock-interfaces:   /usr/share/doc/haskell-ed25519/html/ed25519.haddock
haddock-html:         /usr/share/doc/haskell-ed25519/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ed25519-0.0.5.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ed25519.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ed25519
version:              0.0.5.0
visibility:           public
id:                   ed25519-0.0.5.0-2HPHlG3Gt2q4hOFuy7glcE
key:                  ed25519-0.0.5.0-2HPHlG3Gt2q4hOFuy7glcE
license:              MIT
copyright:            Copyright (c) Austin Seipp 2013-2015
maintainer:           Austin Seipp <aseipp@pobox.com>
author:               Austin Seipp
homepage:             http://thoughtpolice.github.com/hs-ed25519
synopsis:             Ed25519 cryptographic signatures
description:
    This package provides a simple, fast, self-contained copy of the
    Ed25519 public-key signature system with a clean interface. It also
    includes support for detached signatures, and thorough documentation
    on the design and implementation, including usage guidelines.

category:             Cryptography
abi:                  b05e05d811d1b94a5ca345695888065e
exposed:              True
exposed-modules:      Crypto.Sign.Ed25519
import-dirs:          /usr/lib/ghc-8.10.2/site-local/ed25519-0.0.5.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/ed25519-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/ed25519-0.0.5.0
hs-libraries:         HSed25519-0.0.5.0-2HPHlG3Gt2q4hOFuy7glcE
depends:              base-4.14.1.0 bytestring-0.10.10.0 ghc-prim-0.6.1
haddock-interfaces:   /usr/share/doc/haskell-ed25519/html/ed25519.haddock
haddock-html:         /usr/share/doc/haskell-ed25519/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
